%bcond_with tests
%bcond_with signed

%global goipath         github.com/osbuild/weldr-client/v2

Summary:   Command line utility to control osbuild-composer
Name:      weldr-client
Version:   35.9
Release:   1%{?dist}
License:   Apache-2.0

Url:       github.com/osbuild/weldr-client
Source0:   https://github.com/osbuild/weldr-client/releases/download/v%{version}/%{name}-%{version}.tar.gz
%if %{with signed}
Source1:   https://github.com/osbuild/weldr-client/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source2:   https://keys.openpgp.org/vks/v1/by-fingerprint/117E8C168EFE3A7F#/gpg-117E8C168EFE3A7F.key
%endif

Provides: composer-cli = %{version}-%{release}
Requires: diffutils
BuildRequires: golang
BuildRequires: git-core
BuildRequires: make
BuildRequires: gnupg2
BuildRequires: go-rpm-macros

%description
Command line utility to control osbuild-composer

%if %{with tests}
%package tests
Summary:    Integration tests for composer-cli

Requires: createrepo_c

%description tests
Integration tests to be run on a pristine-dedicated system to test the
composer-cli package.
%endif

%prep
%autosetup -p1

%build
export LDFLAGS="-X %{goipath}/cmd/composer-cli/root.Version=%{version} "

GO_BUILD_PATH=$PWD/_build
install -m 0755 -vd $(dirname $GO_BUILD_PATH/src/%{goipath})
ln -fs $PWD $GO_BUILD_PATH/src/%{goipath}
cd $GO_BUILD_PATH/src/%{goipath}
install -m 0755 -vd _bin
export PATH=$PWD/_bin${PATH:+:$PATH}
export GOPATH=$GO_BUILD_PATH:$GOPATH
export GOFLAGS=-mod=vendor

%gobuild -o composer-cli %{goipath}/cmd/composer-cli

%if %{with tests}
export BUILDTAGS="integration"
export LDFLAGS="${LDFLAGS:-} -linkmode=external -compressdwarf=false -B 0x$(od -N 20 -An -tx1 -w100 /dev/urandom | tr -d ' ')"
go test -c -tags=integration -buildmode pie -compiler gc -ldflags="${LDFLAGS}" -o composer-cli-tests %{goipath}/weldr
%endif

%install
make DESTDIR=%{buildroot} install

%if %{with tests}
make DESTDIR=%{buildroot} install-tests
%endif

%check
export LDFLAGS="-X %{goipath}/cmd/composer-cli/root.Version=%{version} "
make test

%files
%license LICENSE
%doc examples HACKING.md README.md
%{_bindir}/composer-cli
%dir %{_sysconfdir}/bash_completion.d
%{_sysconfdir}/bash_completion.d/composer-cli
%{_mandir}/man1/composer-cli*

%if %{with tests}
%files tests
%license LICENSE
%{_libexecdir}/tests/composer-cli/
%endif


%changelog
* Tue Oct 31 2023 Fanjun Kong <fanjunkong@tencent.com> - 35.9-1
- support for oc9
